:orphan:

.. _source:


Detailed documentation of all internal modules
===============================================

.. todo:: This is not yet complete, see `issue #52 <http://www.github.com/SeitaBV/flexmeasures/pull/52>`_


app
---

.. automodule:: flexmeasures.app
    :members:


data.models
-----------

.. automodule:: flexmeasures.data.models
    :members:


utils
-------

.. automodule:: flexmeasures.utils
    :members:

utils.calculations
~~~~~~~~~~~~~~~~~~~~

.. automodule:: flexmeasures.utils.calculations
    :members:

utils.time_utils
~~~~~~~~~~~~~~~~~

.. automodule:: flexmeasures.utils.time_utils
    :members:

ui.utils.view_utils
~~~~~~~~~~~~~~~~~~~

.. automodule:: flexmeasures.ui.utils.view_utils
    :members:

 utils.forecasting_utils
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: flexmeasures.utils.forecasting_utils
    :members:

ui.utils.plotting_utils
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: flexmeasures.ui.utils.plotting_utils
    :members:



ui.views
--------

.. automodule:: flexmeasures.ui.views.dashboard
    :members:

.. automodule:: flexmeasures.ui.views.portfolio
    :members:

.. automodule:: flexmeasures.ui.views.control
    :members:

.. automodule:: flexmeasures.ui.views.analytics
    :members:

